summaryrefslogtreecommitdiff
path: root/public/app/views/components/breadcrumbs.php
diff options
context:
space:
mode:
Diffstat (limited to 'public/app/views/components/breadcrumbs.php')
-rw-r--r--public/app/views/components/breadcrumbs.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/public/app/views/components/breadcrumbs.php b/public/app/views/components/breadcrumbs.php
index 471cfb6..90b4af9 100644
--- a/public/app/views/components/breadcrumbs.php
+++ b/public/app/views/components/breadcrumbs.php
@@ -5,7 +5,7 @@
* imported variables
* ---
* @param $id : category_id of last level
* @param $title : category title of last level
* @param $parents : array of parent nodes
* -----------------------------------------------------------------------------
*/
@@ -18,13 +18,13 @@
<!-- parent nodes -->
<?php if ($id != 0) : ?>
<?php foreach($parents as $node) : ?>
- <i class="fas fa-angle-right"></i> <a href="/wiki/category?id=<?=$node['id']?>"><?=$node['title']?></a>
+ <i class="fas fa-angle-right"></i> <a href="/course/<?=$node['id']?>"><?=$node['label']?></a>
<?php endforeach; ?>
<?php endif; ?>
<!-- last (current) node -->
<?php if ($id != 0) : ?>
- <i class="fas fa-angle-right"></i> <a href="/wiki/category?id=<?=$id?>"><?=$title?></a>
+ <i class="fas fa-angle-right"></i> <a href="/course/<?=$id?>"><?=$label?></a>
<?php endif; ?>
</div> \ No newline at end of file
@@ -5,7 +5,7 @@
* ---
* @param $id : category_id of last level
- * @param $title : category title of last level
+ * @param $label : category title of last level
* @param $parents : array of parent nodes
* -----------------------------------------------------------------------------